==============
Wagtail OAuth2
==============

.. image:: https://readthedocs.org/projects/wagtail-oauth2/badge/?version=latest
   :target: https://wagtail-oauth2.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/Gandi/wagtail-oauth2/actions/workflows/main.yml/badge.svg
   :target: https://github.com/Gandi/wagtail-oauth2/actions/workflows/main.yml
   :alt: Build Status


.. image:: https://codecov.io/gh/Gandi/wagtail-oauth2/branch/main/graph/badge.svg?token=VN14GVV3Y0
   :target: https://codecov.io/gh/Gandi/wagtail-oauth2
   :alt: Coverage


Plugin to replace Wagtail default login by an OAuth2.0 Authorization Server.

What is wagtail-oauth2
----------------------

OAuth2.0 is an authorization framework widely used and usually,
OAuth2.0 authorization servers grant authorization on authenticated user.


The OAuth2 Authorization is used as an **identity provider**.


Read More
---------

You can read the `full documentation of this library here`_.


.. _`full documentation of this library here`: https://wagtail-oauth2.readthedocs.io/en/latest/